package gatetutorial.web;

import gatetutorial.service.GateService;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import gate.Document;
import gate.DocumentFormat;
import gate.Factory;
import gate.Utils;
import gate.util.GateException;

import java.util.Map;
import java.util.Set;

@Controller
public class GateController {

  private static final Logger log = LoggerFactory.getLogger(GateController.class);

  @Autowired
  private GateService gateService;

  @ModelAttribute("allMimeTypes")
  public Set<String> registeredMimeTypes() {
    return DocumentFormat.getSupportedMimeTypes();
  }

  @RequestMapping(value="/", method = RequestMethod.GET)
  public String index(Map<String, Object> model) throws GateException {
    AnnotationRequest req = new AnnotationRequest();
    req.setText("This is some example text");
    model.put("params", req);
    return "index";
  }

  @RequestMapping(value="/", method = RequestMethod.POST)
  public String process(
      @ModelAttribute("params") AnnotationRequest params,
      Map<String, Object> model) throws GateException {

    model.put("params", params);
    Document doc = null;
    try {
      log.debug("Creating document");
      doc = (Document)Factory.createResource("gate.corpora.DocumentImpl",
                  Utils.featureMap("stringContent", params.getText(),
                                   "mimeType", params.getMimeType()));
      model.put("features", gateService.processWithGate(doc));
    } finally {
      Factory.deleteResource(doc);
    }

    return "index";
  }
}
